==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-fms/include/aws/fms/model/ListPoliciesRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/fms/FMS_EXPORTS.h>
#include <aws/fms/FMSRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace FMS
{
namespace Model
{

  /**
   */
  class AWS_FMS_API ListPoliciesRequest : public FMSRequest
  {
  public:
    ListPoliciesRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "ListPolicies"; }

    Aws::String SerializePayload() const override;

    Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;


    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline ListPoliciesRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline ListPoliciesRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline ListPoliciesRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}


    /**
     * <p>Specifies the number of <code>PolicySummary</code> objects that you want
     * Firewall Manager to return for this request. If you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, the response includes a <code>NextToken</code> value
     * that you can use to get another batch of <code>PolicySummary</code> objects.</p>
     */
    inline int GetMaxResults() const{ return m_maxResults; }

    /**
     * <p>Specifies the number of <code>PolicySummary</code> objects that you want
     * Firewall Manager to return for this request. If you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, the response includes a <code>NextToken</code> value
     * that you can use to get another batch of <code>PolicySummary</code> objects.</p>
     */
    inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }

    /**
     * <p>Specifies the number of <code>PolicySummary</code> objects that you want
     * Firewall Manager to return for this request. If you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, the response includes a <code>NextToken</code> value
     * that you can use to get another batch of <code>PolicySummary</code> objects.</p>
     */
    inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }

    /**
     * <p>Specifies the number of <code>PolicySummary</code> objects that you want
     * Firewall Manager to return for this request. If you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, the response includes a <code>NextToken</code> value
     * that you can use to get another batch of <code>PolicySummary</code> objects.</p>
     */
    inline ListPoliciesRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}

  private:

    Aws::String m_nextToken;
    bool m_nextTokenHasBeenSet;

    int m_maxResults;
    bool m_maxResultsHasBeenSet;
  };

} // namespace Model
} // namespace FMS
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-fms/include/aws/fms/model/ListPoliciesRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/fms/FMS_EXPORTS.h>
#include <aws/fms/FMSRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace FMS
{
namespace Model
{

  /**
   */
  class AWS_FMS_API ListPoliciesRequest : public FMSRequest
  {
  public:
    ListPoliciesRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "ListPolicies"; }

    Aws::String SerializePayload() const override;

    Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;


    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline const Aws::String& GetNextToken() const{ return m_nextToken; }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline ListPoliciesRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline ListPoliciesRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}

    /**
     * <p>If you specify a value for <code>MaxResults</code> and you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, Firewall Manager returns a <code>NextToken</code> value
     * in the response that allows you to list another group of
     * <code>PolicySummary</code> objects. For the second and subsequent
     * <code>ListPolicies</code> requests, specify the value of <code>NextToken</code>
     * from the previous response to get information about another batch of
     * <code>PolicySummary</code> objects.</p>
     */
    inline ListPoliciesRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}


    /**
     * <p>Specifies the number of <code>PolicySummary</code> objects that you want
     * Firewall Manager to return for this request. If you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, the response includes a <code>NextToken</code> value
     * that you can use to get another batch of <code>PolicySummary</code> objects.</p>
     */
    inline int GetMaxResults() const{ return m_maxResults; }

    /**
     * <p>Specifies the number of <code>PolicySummary</code> objects that you want
     * Firewall Manager to return for this request. If you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, the response includes a <code>NextToken</code> value
     * that you can use to get another batch of <code>PolicySummary</code> objects.</p>
     */
    inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }

    /**
     * <p>Specifies the number of <code>PolicySummary</code> objects that you want
     * Firewall Manager to return for this request. If you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, the response includes a <code>NextToken</code> value
     * that you can use to get another batch of <code>PolicySummary</code> objects.</p>
     */
    inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }

    /**
     * <p>Specifies the number of <code>PolicySummary</code> objects that you want
     * Firewall Manager to return for this request. If you have more
     * <code>PolicySummary</code> objects than the number that you specify for
     * <code>MaxResults</code>, the response includes a <code>NextToken</code> value
     * that you can use to get another batch of <code>PolicySummary</code> objects.</p>
     */
    inline ListPoliciesRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}

  private:

    Aws::String m_nextToken;
    bool m_nextTokenHasBeenSet = false;

    int m_maxResults;
    bool m_maxResultsHasBeenSet = false;
  };

} // namespace Model
} // namespace FMS
} // namespace Aws
